@@ -1735,6 +1735,14 @@ class Update(MethodsInterface):
         new_portage_state_hash = ps.get_state()
         ini.setVar('system', {'portage_hash': new_portage_state_hash})
         return True
+    
+    def drop_portage_state_hash(self):
+        """
+        Сбросить состояние
+        """
+        ini = SystemIni(self.clVars)
+        ini.delVar('system', 'portage_hash')
+        return True
 
     def update_fastlogin_domain_path(self):
         try:
